@@ -1,7 +1,7 @@
 use strict;
 package HTTP::BrowserDetect;
 BEGIN {
-  $HTTP::BrowserDetect::VERSION = '1.24';
+  $HTTP::BrowserDetect::VERSION = '1.25';
 }
 
 use vars qw(@ISA @EXPORT @EXPORT_OK @ALL_TESTS);
@@ -58,8 +58,7 @@ push @ALL_TESTS, qw(
     aol5        aol6        neoplanet
     neoplanet2  avantgo     emacs
     mozilla     gecko       r1
-    iceweasel   netfront    mobile_safari
-    elinks
+    elinks      netfront    mobile_safari
 );
 
 # Firefox variants
@@ -526,6 +525,7 @@ sub _test {
             || index( $ua, "symbos" ) != -1
             || index( $ua, "opera mobi" ) != -1
             || index( $ua, "fennec" ) != -1
+            || index( $ua, "opera tablet" ) != -1
             || $tests->{PSP}
     );
 
@@ -1109,7 +1109,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 SYNOPSIS
 
@@ -1145,7 +1145,7 @@ The HTTP::BrowserDetect object does a number of tests on an HTTP user agent
 string. The results of these tests are available via methods of the object.
 
 This module is based upon the JavaScript browser detection code available at
-B<http://www.mozilla.org/docs/web-developer/sniffer/browser_type.html>.
+L<http://www.mozilla.org/docs/web-developer/sniffer/browser_type.html>.
 
 =head1 INSTALLATION
 
@@ -1560,6 +1560,8 @@ Olivier Bilodeau
 
 Yoshiki Kurihara
 
+Paul Findlay
+
 =head1 TO DO
 
 The _engine() method currently only handles Gecko.  It needs to be expanded to
@@ -1569,16 +1571,18 @@ POD coverage is also not 100%.
 
 =head1 SEE ALSO
 
-"The Ultimate JavaScript Client Sniffer, Version 3.0", B<http://www.mozilla.org/docs/web-developer/sniffer/browser_type.html>
+"The Ultimate JavaScript Client Sniffer, Version 3.0", L<http://www.mozilla.org/docs/web-developer/sniffer/browser_type.html>
 
-"Browser ID (User-Agent) Strings", B<http://www.zytrax.com/tech/web/browser_ids.htm>
+"Browser ID (User-Agent) Strings", L<http://www.zytrax.com/tech/web/browser_ids.htm>
 
-Safari "Historical User Agent strings", B<http://developer.apple.com/internet/safari/uamatrix.html> (now gone, retrieved 2007-06-20)
+Safari "Historical User Agent strings", L<http://developer.apple.com/internet/safari/uamatrix.html> (now gone, retrieved 2007-06-20)
 
-"Safari Agent Strings", B<http://homepage.mac.com/jprince/designSandbox/web/safari-agents/>
+"Safari Agent Strings", L<http://homepage.mac.com/jprince/designSandbox/web/safari-agents/>
 
 perl(1), L<HTTP::Headers>, L<HTTP::Headers::UserAgent>.
 
+=head1
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -1593,9 +1597,9 @@ You can also look for information at:
 
 L<http://github.com/oalders/http-browserdetect>
 
-=item * RT: CPAN's request tracker
+=item * Reporting Issues
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTTP-BrowserDetect>
+L<https://github.com/oalders/http-browserdetect/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -1607,7 +1611,7 @@ L<http://cpanratings.perl.org/d/HTTP-BrowserDetect>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/HTTP-BrowserDetect/>
+Lhttp://beta.metacpan.org/module/HTTP::BrowserDetect>
 
 =back
 
@@ -1620,12 +1624,16 @@ have many more UserAgent strings to test against.
 
 Patches are certainly welcome, with many thanks for the excellent
 contributions which have already been received. The preferred method of
-patching would be to fork the GitHub repo and then send me a pull requests,
+patching would be to fork the GitHub repo and then send me a pull request,
 but plain old patch files are also welcome.
 
 If you're able to add test cases, this will speed up the time to release your
 changes. Just edit t/useragents.json so that the test coverage includes any
-changes you have made.  Please contact me if you have any questions.
+changes you have made. Please contact me if you have any questions.
+
+This distribution uses L<Dist::Zilla>. If you're not familiar with this
+module, please see L<https://github.com/oalders/http-browserdetect/issues/5>
+for some helpful tips to get you started.
 
 =head1 AUTHORS
 
